library(testthat)
library(divseg)

data('de_county')

test_check('divseg')
